AdaptiveColumn class

A column that adapts its layout based on screen size

Inheritance

Constructors

AdaptiveColumn({Key? key, required List<Widget> children, double spacing = 8.0, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.start, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.center, bool convertToRowOnDesktop = true, bool reverse = false, MainAxisSize mainAxisSize = MainAxisSize.min, MainAxisAlignment? rowMainAxisAlignment, CrossAxisAlignment? rowCrossAxisAlignment, double? rowSpacing})
Constructor for AdaptiveColumn
const

Properties

children List<Widget>
List of children widgets to display in the column
final
convertToRowOnDesktop bool
Whether to convert to a row on desktop screens
final
crossAxisAlignment CrossAxisAlignment
Cross axis alignment of the column
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mainAxisAlignment MainAxisAlignment
Main axis alignment of the column
final
mainAxisSize MainAxisSize
Main axis size of the column
final
reverse bool
Whether to reverse the order of items
final
rowCrossAxisAlignment CrossAxisAlignment?
Cross axis alignment when converted to a row
final
rowMainAxisAlignment MainAxisAlignment?
Main axis alignment when converted to a row
final
rowSpacing double?
Spacing between items when converted to a row
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing double
Spacing between items in the column
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited