ResponsiveConfig class

Configuration class for responsive widgets

Constructors

ResponsiveConfig({double mobileBreakpoint = 600.0, double tabletBreakpoint = 900.0, double desktopBreakpoint = 1200.0, double largeDesktopBreakpoint = 1800.0})
Constructor with default values
const

Properties

desktopBreakpoint double
Default breakpoint for desktop screens
final
hashCode int
The hash code for this object.
no setterinherited
largeDesktopBreakpoint double
Default breakpoint for large desktop screens
final
mobileBreakpoint double
Default breakpoint for mobile screens
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tabletBreakpoint double
Default breakpoint for tablet screens
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

defaultConfig ResponsiveConfig
Default configuration for responsive widgets
final
instance ResponsiveConfig
Get the current active configuration
no setter

Static Methods

setConfig(ResponsiveConfig config) → void
Set a new configuration as the active one