ResponsiveContainer class

A container that adapts its size based on screen size

Inheritance

Constructors

ResponsiveContainer({Key? key, required Widget child, double mobileWidthFraction = 1.0, double tabletWidthFraction = 0.8, double desktopWidthFraction = 0.6, double? mobileMaxWidth, double? tabletMaxWidth, double? desktopMaxWidth, double? height, double? minHeight, double? maxHeight, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? margin, Alignment? alignment, BoxDecoration? decoration})
Constructor for ResponsiveContainer
const

Properties

alignment Alignment?
Alignment of the child within the container
final
child Widget
Child widget
final
decoration BoxDecoration?
Decoration of the container
final
desktopMaxWidth double?
Maximum width on desktop screens
final
desktopWidthFraction double
Width percentage on desktop screens (0.0 to 1.0)
final
hashCode int
The hash code for this object.
no setterinherited
height double?
Height of the container
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin EdgeInsetsGeometry?
Margin around the container
final
maxHeight double?
Maximum height of the container
final
minHeight double?
Minimum height of the container
final
mobileMaxWidth double?
Maximum width on mobile screens
final
mobileWidthFraction double
Width percentage on mobile screens (0.0 to 1.0)
final
padding EdgeInsetsGeometry?
Padding inside the container
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tabletMaxWidth double?
Maximum width on tablet screens
final
tabletWidthFraction double
Width percentage on tablet screens (0.0 to 1.0)
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited