ResponsiveGridView class

A responsive grid view that can be scrolled

Inheritance

Constructors

ResponsiveGridView({Key? key, required List<Widget> children, int mobileColumns = 1, int tabletColumns = 2, int desktopColumns = 4, int largeDesktopColumns = 6, double crossAxisSpacing = 8.0, double mainAxisSpacing = 8.0, double childAspectRatio = 1.0, bool useMaxCrossAxisExtent = false, double? maxCrossAxisExtent, EdgeInsetsGeometry? padding, ScrollController? controller, ScrollPhysics? physics, bool? primary})
Constructor for ResponsiveGridView
const

Properties

childAspectRatio double
Aspect ratio of each grid item
final
children List<Widget>
List of children widgets to display in the grid
final
controller ScrollController?
Scroll controller for the grid
final
crossAxisSpacing double
Spacing between columns
final
desktopColumns int
Number of columns to show on desktop screens
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
largeDesktopColumns int
Number of columns to show on large desktop screens
final
mainAxisSpacing double
Spacing between rows
final
maxCrossAxisExtent double?
Maximum cross axis extent when useMaxCrossAxisExtent is true
final
mobileColumns int
Number of columns to show on mobile screens
final
padding EdgeInsetsGeometry?
Padding around the grid
final
physics ScrollPhysics?
Scroll physics for the grid
final
primary bool?
Primary scroll view
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tabletColumns int
Number of columns to show on tablet screens
final
useMaxCrossAxisExtent bool
Whether to use a fixed cross axis count or a max cross axis extent
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited