ResponsiveText class

A text widget that adapts its size based on screen size

Inheritance

Constructors

ResponsiveText(String text, {Key? key, TextStyle? mobileStyle, TextStyle? tabletStyle, TextStyle? desktopStyle, TextStyle? largeDesktopStyle, TextAlign? textAlign, TextOverflow? overflow, int? maxLines, bool? softWrap, double? textScaleFactor})
Constructor for ResponsiveText
const

Properties

desktopStyle TextStyle?
Text style for desktop screens
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
largeDesktopStyle TextStyle?
Text style for large desktop screens
final
maxLines int?
Maximum number of lines
final
mobileStyle TextStyle?
Text style for mobile screens
final
overflow TextOverflow?
Text overflow behavior
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
softWrap bool?
Whether to softwrap text
final
tabletStyle TextStyle?
Text style for tablet screens
final
text String
Text to display
final
textAlign TextAlign?
Text alignment
final
textScaleFactor double?
Text scaling factor
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited