ResponsiveValue<T> class
A class that provides different values based on screen size
Constructors
- ResponsiveValue({required T mobile, T? tablet, T? desktop, T? largeDesktop})
-
Constructor for ResponsiveValue
const
Properties
- desktop → T?
-
Value for desktop screens
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- largeDesktop → T?
-
Value for large desktop screens
final
- mobile → T
-
Value for mobile screens
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tablet → T?
-
Value for tablet screens
final
Methods
-
copyWith(
{T? mobile, T? tablet, T? desktop, T? largeDesktop}) → ResponsiveValue< T> - Create a new ResponsiveValue with updated values
-
get(
BuildContext context) → T - Get the value based on the current screen size
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited