ResponsiveScaffold class
A responsive scaffold that adapts its layout based on screen size
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- ResponsiveScaffold
Constructors
- ResponsiveScaffold({Key? key, PreferredSizeWidget? appBar, required Widget body, Widget? drawer, Widget? floatingActionButton, FloatingActionButtonLocation? floatingActionButtonLocation, bool showDrawerOnDesktop = false, Color? backgroundColor, bool? resizeToAvoidBottomInset})
-
Constructor for ResponsiveScaffold
const
Properties
- appBar → PreferredSizeWidget?
-
App bar for the scaffold
final
- backgroundColor → Color?
-
Background color of the scaffold
final
- body → Widget
-
Body of the scaffold
final
-
Bottom navigation bar for mobile screens
final
- drawer → Widget?
-
Drawer for mobile and tablet screens
final
- floatingActionButton → Widget?
-
Floating action button
final
- floatingActionButtonLocation → FloatingActionButtonLocation?
-
Floating action button location
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
Navigation rail for desktop screens
final
-
Width of the navigation rail
final
- resizeToAvoidBottomInset → bool?
-
Whether to resize the body to avoid bottom insets
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showDrawerOnDesktop → bool
-
Whether to show the drawer on desktop screens
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited